#!/bin/sh

# All Rights Reserved * Licensed Materials - Property of IBM
# US Government Users Restricted Rights - Use, duplication or disclosure
# restricted by GSA ADP Schedule Contract with IBM Corp.

#set -o xtrace 

CUR_DIR=`pwd`
binDir=`dirname "$0"`
if [ -r "${binDir}/setupCmdLine.sh" ]; then
. "${binDir}/setupCmdLine.sh"
fi




if [ -f ${JAVA_HOME}/bin/java ]; then
    JAVA_EXE="${JAVA_HOME}/bin/java"
else
    JAVA_EXE="${JAVA_HOME}/jre/bin/java"
fi

function usage() {
echo "" 
echo "Command invocation example"
echo ""
echo "./bpmdc.sh -type=General -PMR=(pmrNumber) -config=yes -uploadToIBM=yes -outputDirectory=(location of output directory)"
echo " where type=General / Install 	{Optional}  {Defaults to General}" 
echo "  PMR in 11111.bbb.CCC format	{Optional}  {Defaults to none, No upload}"
echo "  config option to collect the config directory {Optional}  {Defaults to No}"
echo "  uploadToIBM to send the collected data with FTP option {Optional} {Defaults to No}"
echo "  outputDirectory is the location where you want to create the output zip { Defaults to WAS_HOME/BPM/isadc folder }"
echo "  -help to display help"
echo "" 		
echo "If invoked without any option then the default options will be picked."
echo "The Default options are"
echo "-type=General -config=no -uploadToIBM=No {PMR not needed} -outputDirectory=(Full path to collection)"

}

# #${USER_INSTALL_ROOT}/bin/isadc should be set to the place where ISA DC core is 

ISADC_HOME="$WAS_HOME/BPM/isadc"
OUTPUTDIRECTORY=$ISADC_HOME
if [ "$1" == "" ]; then

	COLLECTORTYPE=""
	UPLOAD="false" 
	CONFIG="false"
	PMRNUMBER=""
	
#	echo "start running isadc"  
fi

while [ "$1" != "" ]; do
	PARAM=`echo $1 | awk -F= '{print $1}'`
    VALUE=`echo $1 | awk -F= '{print $2}'`
    case $PARAM in
        -[hH]  | -[hH][eE][lL][pP] )
            usage
            exit
            ;;
        -[tT][yY][pP][eE] | -[cC][oO][lL][lL][eE][cC][tT][oO][rR][tT][yY][pP][eE] )
            COLLECTORTYPE=$VALUE
            ;;
        -[cC][oO][nN][fF][iI][gG])
            CONFIG=$VALUE
            ;;
        -[uU][pP][lL][oO][aA][dD][tT][oO][iI][bB][mM])
            UPLOAD=$VALUE
            ;;
        -[pP][mM][rR])
            PMRNUMBER=$VALUE
            ;;
        -[oO][uU][tT][pP][uU][tT][dD][iI][rR][eE][cC][tT][oO][rR][yY] )
        	OUTPUTDIRECTORY=$VALUE
        	;;
        *)
            echo "ERROR: unknown parameter \"$PARAM\""
            usage
            exit 1
            ;;
    esac
shift
done

if [ "$COLLECTORTYPE" == "" ]; then
COLLECTORTYPE="General" 
fi

if [ "$COLLECTORTYPE" != "General" ]  && [ "$COLLECTORTYPE" != "general" ] && [ "$COLLECTORTYPE" != "Install" ] && [ "$COLLECTORTYPE" != "install" ]; then
usage
exit 1
fi


if [ "$UPLOAD" == "" ]; then
UPLOAD="false"
fi

if [ "$CONFIG" == "" ]; then
CONFIG="false"
fi

if [ "$PMRNUMBER" == "" ]; then
UPLOAD="false"
else  
isValidPMR=false
isValidLength=false

#validate PMR format 
#lengthofPMR=echo 'expr length "$PMRNUMBER"'
lengthofPMR=$(expr length $PMRNUMBER)
# check if length is 15

if [ "$lengthofPMR" == "15" ]; then
	isValidLength=true
fi

firstDot=$(expr index "$PMRNUMBER" ,.)
	if [ "$firstDot" == "6" ]; then 
		remainStr=${PMRNUMBER:6}
		secondDot=$(expr index "$remainStr" ,.)
		if [ "$secondDot" == "4" ]; then
			remainStr1=${remainStr:4}
			thirdDot=$(expr index "$remainStr1" ,.)
			if [ "$thirdDot" == "0" ]; then 
				isValidPMR=true
			fi
		fi
	fi

if [ "$isValidPMR" != "true" ]  || [ "$isValidLength" != "true" ]; then
echo ""
echo "Wrong PMR format - $PMRNUMBER" 
echo "PMR Format should be PPPPP.BBB.CCC"
echo "where PPPPP is PMR Number, BBB is the branch and CCC is the country code."
usage
exit 1
fi

fi


if [ "$OUTPUTDIRECTORY" != "$ISADC_HOME" ]; then
	if [ ! -d $OUTPUTDIRECTORY ]
   		then
      		mkdir -p $OUTPUTDIRECTORY
	fi

fi

DATE_TIME=$(date +"%Y%m%d_%H%M%S")

if [ "$PMRNUMBER" != "" ]; then
	if [ "$UPLOAD" == "false" ]; then
		COLLECT_FILENAME="$OUTPUTDIRECTORY"/"$PMRNUMBER"_"$COLLECTORTYPE"_"$DATE_TIME".zip
	else 
		COLLECT_FILENAME="$OUTPUTDIRECTORY"/"$COLLECTORTYPE"_"$DATE_TIME".zip
		FILENAME_ECUREP="$OUTPUTDIRECTORY"/"$PMRNUMBER"."$COLLECTORTYPE"_"$DATE_TIME".zip
	fi
else 
	COLLECT_FILENAME="$OUTPUTDIRECTORY"/"$COLLECTORTYPE"_"$DATE_TIME".zip
fi



#RESP_FILE="ISADC_HOME/util/ResponseFile.txt"
#PROP_FILE="ISADC_HOME/util/properties.txt" 
RESP_FILE="$ISADC_HOME/util/ResponseFile.txt"
PROP_FILE="$ISADC_HOME/util/properties.txt" 
echo "### Begin Response File" > $RESP_FILE
echo "### Begin Properties File" > $PROP_FILE

echo "10.CollectionZipName=$COLLECT_FILENAME" >> $RESP_FILE
echo "20.YesNo=1" >> $RESP_FILE
if [ "$COLLECTORTYPE" == "General" ]  || [ "$COLLECTORTYPE" == "general" ]; then  
echo "30.CollectionOption=1" >> $RESP_FILE
fi 
if [ "$COLLECTORTYPE" == "Install" ] || [ "$COLLECTORTYPE" == "install" ]; then 
echo "30.CollectionOption=2" >> $RESP_FILE
fi
 
if [ "$CONFIG" == "yes" ] || [ "$CONFIG" == "Yes" ] || [ "$CONFIG" == "YES" ] || [ "$CONFIG" == "y" ] || [ "$CONFIG" == "Y" ]; then 
echo "config=true">> $PROP_FILE
else 
echo "config=$CONFIG">> $PROP_FILE
fi


if [ "$UPLOAD" == "yes" ] || [ "$UPLOAD" == "Yes" ] || [ "$UPLOAD" == "YES" ] || [ "$UPLOAD" == "y" ] || [ "$UPLOAD" == "Y" ]; then
echo "upload=$UPLOAD">> $PROP_FILE
echo "pmr.number=$PMRNUMBER">> $PROP_FILE

echo "40.SelectListOption=2">> $RESP_FILE
echo "50.OptionToCompleteInputDialog=1" >> $RESP_FILE
echo "60.MultipleChoiceInputRequest=1" >> $RESP_FILE

else 
echo "40.SelectListOption=4" >> $RESP_FILE
echo "50.OptionToCompleteInputDialog=1" >> $RESP_FILE
fi


#invoke Command

#

#Set license
LAPSTATUS_HOME=$ISADC_HOME/lap_status
LICENSE_HOME=$ISADC_HOME/licenses
CONSOLE_MODE=-text_only
if [ ! -d $LAPSTATUS_HOME ];
then
mkdir $LAPSTATUS_HOME 
fi
if [ ! -d $LAPSTATUS_HOME/license ];
then
mkdir $LAPSTATUS_HOME/license
fi
#if test -f $ISADC_HOME/lap_status/license/status.dat 
#then
#cp $ISADC_HOME/lap_status/license/status.dat $LAPSTATUS_HOME/license/status.dat
#fi

if [ ! -f $ISADC_HOME/lap_status/license/status.dat ];
then
echo "Running License Acceptance Process Tool"
$JAVA_EXE -cp $LICENSE_HOME/LAPApp.jar  com.ibm.lex.lapapp.LAP -l $LICENSE_HOME -s $LAPSTATUS_HOME  $CONSOLE_MODE
fi

#Check to see if license was accepted 
if [ -f $LAPSTATUS_HOME/license/status.dat ];
then
echo "Running the Collector command with the following options"
echo "/-------------------------------------------------------------------------------"
echo "type = $COLLECTORTYPE"
echo "config = $CONFIG"
echo "uploadToIBM = $UPLOAD"
echo "PMR = $PMRNUMBER"
echo "outputDirectory = $OUTPUTDIRECTORY"
echo "\-------------------------------------------------------------------------------"
echo ""
echo "The collection is beginning and could take a few minutes depending on the size."

"$ISADC_HOME/isadc.sh" -silent "$ISADC_HOME/util/ResponseFile.txt" > "$ISADC_HOME/util/ResponseLog.txt"  2>&1
else 
echo "You must accept the license before running ISA Data Collector"
fi

if [ -r $COLLECT_FILENAME ]; then
echo ""
echo "/-------------------------------------------------------------------------------"
echo "^| Your collection file is located at :"
echo "^| $COLLECT_FILENAME"
echo "\-------------------------------------------------------------------------------"
echo ""
echo "Collection is complete"
exit 0
else 
	if  [ -r $FILENAME_ECUREP ]; then
		echo ""
		echo "/-------------------------------------------------------------------------------"
		echo "^| Your collection file is located at :"
		echo "^| $FILENAME_ECUREP"
		echo "\-------------------------------------------------------------------------------"
		echo ""
		echo "Collection is complete"
		exit 0
	else 
		echo "Collection failed.  Please see logs." 
		exit 1
	fi
fi
